@@ -1,65 +1,64 @@
 extern crate wasmcloud_control_interface;
-use crate::util::{format_ellipsis, format_optional, format_output, OutputKind, WASH_CMD_INFO};
-use log::debug;
+use crate::util::{format_optional, format_output, OutputKind};
 use serde_json::json;
 use term_table::{row::Row, table_cell::*, Table};
 use wasmcloud_control_interface::*;
 
-// Helper output functions, used to ensure consistent output between ctl & standalone commands
-
-pub(crate) fn call_output(error: Option<String>, msg: Vec<u8>, output_kind: &OutputKind) -> String {
-    match error {
-        Some(e) => format_output(
-            format!("\nError invoking actor: {}", e),
-            json!({ "error": e }),
-            &output_kind,
-        ),
-        None => {
-            //TODO(issue #32): String::from_utf8_lossy should be decoder only if one is not available
-            let call_response = String::from_utf8_lossy(&msg);
-            format_output(
-                format!("\nCall response (raw): {}", call_response),
-                json!({ "response": call_response }),
-                &output_kind,
-            )
-        }
-    }
-}
 pub(crate) fn get_hosts_output(hosts: Vec<Host>, output_kind: &OutputKind) -> String {
-    debug!(target: WASH_CMD_INFO, "Hosts:{:?}", hosts);
     match *output_kind {
-        OutputKind::Text { max_width } => hosts_table(hosts, max_width),
+        OutputKind::Text => hosts_table(hosts),
         OutputKind::Json => format!("{}", json!({ "hosts": hosts })),
     }
 }
+
 pub(crate) fn get_host_inventory_output(inv: HostInventory, output_kind: &OutputKind) -> String {
-    debug!(target: WASH_CMD_INFO, "Inventory:{:?}", inv);
     match *output_kind {
-        OutputKind::Text { max_width } => host_inventory_table(inv, max_width),
+        OutputKind::Text => host_inventory_table(inv),
         OutputKind::Json => format!("{}", json!({ "inventory": inv })),
     }
 }
-pub(crate) fn get_claims_output(claims: ClaimsList, output_kind: &OutputKind) -> String {
-    debug!(target: WASH_CMD_INFO, "Claims:{:?}", claims);
+
+pub(crate) fn get_claims_output(claims: GetClaimsResponse, output_kind: &OutputKind) -> String {
     match *output_kind {
-        OutputKind::Text { max_width } => claims_table(claims, max_width),
+        OutputKind::Text => claims_table(claims),
         OutputKind::Json => format!("{}", json!({ "claims": claims })),
     }
 }
-pub(crate) fn link_output(
+
+pub(crate) fn link_del_output(
+    actor_id: &str,
+    contract_id: &str,
+    link_name: &str,
+    failure: Option<String>,
+    output_kind: &OutputKind,
+) -> String {
+    match failure {
+        None => format_output(
+            format!(
+                "\nDeleted link for {} on {} ({}) successfully",
+                actor_id, contract_id, link_name
+            ),
+            json!({"actor_id": actor_id, "contract_id": contract_id, "link_name": link_name, "result": "published"}),
+            output_kind,
+        ),
+        Some(f) => format_output(
+            format!("\nError deleting link: {}", f),
+            json!({ "error": f }),
+            output_kind,
+        ),
+    }
+}
+
+pub(crate) fn link_put_output(
     actor_id: &str,
     provider_id: &str,
     failure: Option<String>,
     output_kind: &OutputKind,
 ) -> String {
-    debug!(
-        target: WASH_CMD_INFO,
-        "Publishing link between {} and {}", actor_id, provider_id
-    );
     match failure {
         None => format_output(
             format!(
-                "\nAdvertised link ({}) <-> ({}) successfully",
+                "\nPublished link ({}) <-> ({}) successfully",
                 actor_id, provider_id
             ),
             json!({"actor_id": actor_id, "provider_id": provider_id, "result": "published"}),
@@ -72,113 +71,71 @@ pub(crate) fn link_output(
         ),
     }
 }
-pub(crate) fn start_actor_output(
-    actor_ref: &str,
-    host_id: &str,
-    failure: Option<String>,
-    output_kind: &OutputKind,
-) -> String {
-    debug!(
-        target: WASH_CMD_INFO,
-        "Sending request to start actor {}", actor_ref
-    );
-    match failure {
-        None => format_output(
-            format!("\nActor starting on host {}", host_id),
-            json!({ "actor_ref": actor_ref, "host_id": host_id }),
-            &output_kind,
-        ),
-        Some(f) => format_output(
-            format!("\nError starting actor: {}", f),
-            json!({ "error": f }),
-            &output_kind,
-        ),
+
+pub(crate) fn link_query_output(list: LinkDefinitionList, output_kind: &OutputKind) -> String {
+    match *output_kind {
+        OutputKind::Text => links_table(list),
+        OutputKind::Json => format!("{}", json!({ "links": list.links })),
     }
 }
-pub(crate) fn start_provider_output(
-    provider_ref: &str,
-    host_id: &str,
-    failure: Option<String>,
-    output_kind: &OutputKind,
-) -> String {
-    debug!(
-        target: WASH_CMD_INFO,
-        "Sending request to start provider {}", provider_ref
-    );
-    match failure {
-        None => format_output(
-            format!("\nProvider starting on host {}", host_id),
-            json!({ "provider_ref": provider_ref, "host_id": host_id}),
-            output_kind,
-        ),
-        Some(e) => format_output(
-            format!("\nError starting provider: {}", e),
-            json!({ "error": e }),
-            output_kind,
-        ),
-    }
+
+pub(crate) fn apply_manifest_output(results: Vec<String>, output_kind: &OutputKind) -> String {
+    format_output(
+        format!("\nManifest application results:\n{}", results.join("\n")),
+        json!({ "results": results }),
+        output_kind,
+    )
 }
-pub(crate) fn stop_actor_output(
-    actor_ref: &str,
-    failure: Option<String>,
+
+pub(crate) fn ctl_operation_output(
+    accepted: bool,
+    success: &str,
+    error: &str,
     output_kind: &OutputKind,
 ) -> String {
-    match failure {
-        Some(f) => format_output(
-            format!("\nError stopping actor: {}", f),
-            json!({ "error": f }),
-            &output_kind,
-        ),
-        None => format_output(
-            format!("\nStopping actor: {}", actor_ref),
-            json!({ "actor_ref": actor_ref }),
-            &output_kind,
-        ),
-    }
-}
-pub(crate) fn stop_provider_output(
-    provider_ref: &str,
-    failure: Option<String>,
-    output_kind: &OutputKind,
-) -> String {
-    match failure {
-        Some(f) => format_output(
-            format!("\nError stopping provider: {}", f),
-            json!({ "error": f }),
-            output_kind,
-        ),
-        None => format_output(
-            format!("\nStopping provider: {}", provider_ref),
-            json!({ "provider_ref": provider_ref }),
-            output_kind,
-        ),
-    }
-}
-pub(crate) fn update_actor_output(
-    actor_id: &str,
-    new_actor_ref: &str,
-    error: Option<String>,
-    output_kind: &OutputKind,
-) -> String {
-    if let Some(e) = error {
+    if accepted {
         format_output(
-            format!("\nError updating actor: {}", e),
-            json!({ "error": e }),
+            format!("\n{}", success),
+            json!({ "accepted": accepted, "error": ""}),
             output_kind,
         )
     } else {
         format_output(
-            format!("\nActor {} updated to {}", actor_id, new_actor_ref),
-            json!({ "accepted": error.is_none() }),
+            format!("\n{}", error),
+            json!({ "accepted": accepted, "error": error}),
             output_kind,
         )
     }
 }
 
-/// Helper function to print a Host list to stdout as a table
-pub(crate) fn hosts_table(hosts: Vec<Host>, max_width: usize) -> String {
+/// Helper function to transform a LinkDefinitionList into a table string for printing
+pub(crate) fn links_table(list: LinkDefinitionList) -> String {
     let mut table = Table::new();
-    crate::util::configure_table_style(&mut table, 2, max_width);
+    crate::util::configure_table_style(&mut table);
+
+    table.add_row(Row::new(vec![
+        TableCell::new_with_alignment("Actor ID", 1, Alignment::Left),
+        TableCell::new_with_alignment("Provider ID", 1, Alignment::Left),
+        TableCell::new_with_alignment("Contract ID", 1, Alignment::Left),
+        TableCell::new_with_alignment("Link Name", 1, Alignment::Left),
+    ]));
+
+    list.links.iter().for_each(|l| {
+        table.add_row(Row::new(vec![
+            TableCell::new_with_alignment(l.actor_id.clone(), 1, Alignment::Left),
+            TableCell::new_with_alignment(l.provider_id.clone(), 1, Alignment::Left),
+            TableCell::new_with_alignment(l.contract_id.clone(), 1, Alignment::Left),
+            TableCell::new_with_alignment(l.link_name.clone(), 1, Alignment::Left),
+        ]))
+    });
+
+    table.render()
+}
+
+/// Helper function to transform a Host list into a table string for printing
+pub(crate) fn hosts_table(hosts: Vec<Host>) -> String {
+    let mut table = Table::new();
+    crate::util::configure_table_style(&mut table);
 
     table.add_row(Row::new(vec![
         TableCell::new_with_alignment("Host ID", 1, Alignment::Left),
@@ -194,14 +151,10 @@ pub(crate) fn hosts_table(hosts: Vec<Host>, max_width: usize) -> String {
     table.render()
 }
 
-/// Helper function to print a HostInventory to stdout as a table
-pub(crate) fn host_inventory_table(inv: HostInventory, max_width: usize) -> String {
+/// Helper function to transform a HostInventory into a table string for printing
+pub(crate) fn host_inventory_table(inv: HostInventory) -> String {
     let mut table = Table::new();
-    crate::util::configure_table_style(&mut table, 4, max_width);
-
-    // TableCells have 1 char padding left and right. See [TableCell::pad_content].
-    let content_padding_width = 2;
-    let max_id_width = crate::util::get_max_column_width(&table, 0) - content_padding_width;
+    crate::util::configure_table_style(&mut table);
 
     table.add_row(Row::new(vec![TableCell::new_with_alignment(
         format!("Host Inventory ({})", inv.host_id),
@@ -229,12 +182,12 @@ pub(crate) fn host_inventory_table(inv: HostInventory, max_width: usize) -> Stri
         )]));
     }
 
+    table.add_row(Row::new(vec![TableCell::new_with_alignment(
+        "",
+        4,
+        Alignment::Center,
+    )]));
     if !inv.actors.is_empty() {
-        table.add_row(Row::new(vec![TableCell::new_with_alignment(
-            "",
-            4,
-            Alignment::Center,
-        )]));
         table.add_row(Row::new(vec![
             TableCell::new_with_alignment("Actor ID", 1, Alignment::Left),
             TableCell::new_with_alignment("Name", 1, Alignment::Left),
@@ -243,11 +196,7 @@ pub(crate) fn host_inventory_table(inv: HostInventory, max_width: usize) -> Stri
         inv.actors.iter().for_each(|a| {
             let a = a.clone();
             table.add_row(Row::new(vec![
-                TableCell::new_with_alignment(
-                    format_ellipsis(a.id, max_id_width),
-                    1,
-                    Alignment::Left,
-                ),
+                TableCell::new_with_alignment(a.id, 1, Alignment::Left),
                 TableCell::new_with_alignment(format_optional(a.name), 1, Alignment::Left),
                 TableCell::new_with_alignment(format_optional(a.image_ref), 2, Alignment::Left),
             ]))
@@ -256,16 +205,15 @@ pub(crate) fn host_inventory_table(inv: HostInventory, max_width: usize) -> Stri
         table.add_row(Row::new(vec![TableCell::new_with_alignment(
             "No actors found",
             4,
-            Alignment::Center,
+            Alignment::Left,
         )]));
     }
-
+    table.add_row(Row::new(vec![TableCell::new_with_alignment(
+        "",
+        4,
+        Alignment::Left,
+    )]));
     if !inv.providers.is_empty() {
-        table.add_row(Row::new(vec![TableCell::new_with_alignment(
-            "",
-            4,
-            Alignment::Center,
-        )]));
         table.add_row(Row::new(vec![
             TableCell::new_with_alignment("Provider ID", 1, Alignment::Left),
             TableCell::new_with_alignment("Name", 1, Alignment::Left),
@@ -275,11 +223,7 @@ pub(crate) fn host_inventory_table(inv: HostInventory, max_width: usize) -> Stri
         inv.providers.iter().for_each(|p| {
             let p = p.clone();
             table.add_row(Row::new(vec![
-                TableCell::new_with_alignment(
-                    format_ellipsis(p.id, max_id_width),
-                    1,
-                    Alignment::Left,
-                ),
+                TableCell::new_with_alignment(p.id, 1, Alignment::Left),
                 TableCell::new_with_alignment(format_optional(p.name), 1, Alignment::Left),
                 TableCell::new_with_alignment(p.link_name, 1, Alignment::Left),
                 TableCell::new_with_alignment(format_optional(p.image_ref), 1, Alignment::Left),
@@ -296,10 +240,10 @@ pub(crate) fn host_inventory_table(inv: HostInventory, max_width: usize) -> Stri
     table.render()
 }
 
-/// Helper function to print a ClaimsList to stdout as a table
-pub(crate) fn claims_table(list: ClaimsList, max_width: usize) -> String {
+/// Helper function to transform a ClaimsList into a table string for printing
+pub(crate) fn claims_table(list: GetClaimsResponse) -> String {
     let mut table = Table::new();
-    crate::util::configure_table_style(&mut table, 2, max_width);
+    crate::util::configure_table_style(&mut table);
 
     table.add_row(Row::new(vec![TableCell::new_with_alignment(
         "Claims",
@@ -311,7 +255,7 @@ pub(crate) fn claims_table(list: ClaimsList, max_width: usize) -> String {
         table.add_row(Row::new(vec![
             TableCell::new_with_alignment("Issuer", 1, Alignment::Left),
             TableCell::new_with_alignment(
-                c.values.get("iss").unwrap_or(&"".to_string()),
+                c.get("iss").unwrap_or(&"".to_string()),
                 1,
                 Alignment::Left,
             ),
@@ -319,7 +263,7 @@ pub(crate) fn claims_table(list: ClaimsList, max_width: usize) -> String {
         table.add_row(Row::new(vec![
             TableCell::new_with_alignment("Subject", 1, Alignment::Left),
             TableCell::new_with_alignment(
-                c.values.get("sub").unwrap_or(&"".to_string()),
+                c.get("sub").unwrap_or(&"".to_string()),
                 1,
                 Alignment::Left,
             ),
@@ -327,7 +271,7 @@ pub(crate) fn claims_table(list: ClaimsList, max_width: usize) -> String {
         table.add_row(Row::new(vec![
             TableCell::new_with_alignment("Capabilities", 1, Alignment::Left),
             TableCell::new_with_alignment(
-                c.values.get("caps").unwrap_or(&"".to_string()),
+                c.get("caps").unwrap_or(&"".to_string()),
                 1,
                 Alignment::Left,
             ),
@@ -335,7 +279,7 @@ pub(crate) fn claims_table(list: ClaimsList, max_width: usize) -> String {
         table.add_row(Row::new(vec![
             TableCell::new_with_alignment("Version", 1, Alignment::Left),
             TableCell::new_with_alignment(
-                c.values.get("version").unwrap_or(&"".to_string()),
+                c.get("version").unwrap_or(&"".to_string()),
                 1,
                 Alignment::Left,
             ),
@@ -343,7 +287,7 @@ pub(crate) fn claims_table(list: ClaimsList, max_width: usize) -> String {
         table.add_row(Row::new(vec![
             TableCell::new_with_alignment("Revision", 1, Alignment::Left),
             TableCell::new_with_alignment(
-                c.values.get("rev").unwrap_or(&"".to_string()),
+                c.get("rev").unwrap_or(&"".to_string()),
                 1,
                 Alignment::Left,
             ),
