@@ -314,14 +314,15 @@ pub(crate) fn make_project(
     let (template_base_dir, template_folder, _branch) = prepare_local_template(&args)?;
 
     // read configuration file `project-generate.toml` from template.
-    let project_config_path =
+    let project_config_path = fs::canonicalize(
         locate_project_config_file(CONFIG_FILE_NAME, &template_base_dir, &args.subfolder)
             .with_context(|| {
                 format!(
                     "Invalid template folder: Required configuration file `{}` is missing.",
                     CONFIG_FILE_NAME
                 )
-            })?;
+            })?,
+    )?;
     let mut config = Config::from_path(&project_config_path)?;
     // prevent copying config file to project dir by adding it to the exclude list
     config.exclude(
