@@ -1,6 +1,6 @@
 extern crate oci_distribution;
-use crate::util::{format_output, output_destination, Output, OutputDestination, OutputKind};
-use log::{debug, info};
+use crate::util::{format_output, Output, OutputKind};
+use log::{debug, info, warn};
 use oci_distribution::client::*;
 use oci_distribution::secrets::RegistryAuth;
 use oci_distribution::Reference;
@@ -51,6 +51,9 @@ pub(crate) enum RegCliCommand {
     /// Push an artifact to an OCI compliant registry
     #[structopt(name = "push")]
     Push(PushCommand),
+    /// Ping (test url) to see if the OCI url has an artifact
+    #[structopt(name = "ping")]
+    Ping(PingCommand),
 }
 
 #[derive(StructOpt, Debug, Clone)]
@@ -103,6 +106,16 @@ pub(crate) struct PushCommand {
     pub(crate) opts: AuthOpts,
 }
 
+#[derive(StructOpt, Debug, Clone)]
+pub(crate) struct PingCommand {
+    /// URL of artifact
+    #[structopt(name = "url")]
+    pub(crate) url: String,
+
+    #[structopt(flatten)]
+    pub(crate) opts: AuthOpts,
+}
+
 #[derive(StructOpt, Debug, Clone)]
 pub(crate) struct AuthOpts {
     /// OCI username, if omitted anonymous authentication will be used
@@ -134,18 +147,17 @@ pub(crate) async fn handle_command(
     match command {
         RegCliCommand::Pull(cmd) => handle_pull(cmd).await,
         RegCliCommand::Push(cmd) => handle_push(cmd).await,
+        RegCliCommand::Ping(cmd) => handle_ping(cmd).await,
     }
 }
 
 pub(crate) async fn handle_pull(cmd: PullCommand) -> Result<String, Box<dyn ::std::error::Error>> {
     let image: Reference = cmd.url.parse().unwrap();
     let spinner = match cmd.output.kind {
-        OutputKind::Text { .. } if output_destination() == OutputDestination::Cli => {
-            Some(Spinner::new(
-                Spinners::Dots12,
-                format!(" Downloading {} ...", image.whole()),
-            ))
-        }
+        OutputKind::Text => Some(Spinner::new(
+            &Spinners::Dots12,
+            format!(" Downloading {} ...", image.whole()),
+        )),
         _ => None,
     };
     info!("Downloading {}", image.whole());
@@ -198,6 +210,7 @@ pub(crate) async fn pull_artifact(
         } else {
             ClientProtocol::Https
         },
+        ..Default::default()
     });
 
     let auth = match (user, password) {
@@ -238,12 +251,30 @@ pub(crate) async fn pull_artifact(
         .collect::<Vec<_>>())
 }
 
+pub(crate) async fn handle_ping(cmd: PingCommand) -> Result<String, Box<dyn ::std::error::Error>> {
+    let image: Reference = cmd.url.parse().unwrap();
+    let mut client = Client::new(ClientConfig {
+        protocol: if cmd.opts.insecure {
+            ClientProtocol::Http
+        } else {
+            ClientProtocol::Https
+        },
+        ..Default::default()
+    });
+    let auth = match (cmd.opts.user, cmd.opts.password) {
+        (Some(user), Some(password)) => RegistryAuth::Basic(user, password),
+        _ => RegistryAuth::Anonymous,
+    };
+    let (_, _) = client.pull_manifest(&image, &auth).await?;
+    Ok("Ok".to_string())
+}
+
 pub(crate) fn write_artifact(
     artifact: &[u8],
     image: &Reference,
     output: Option<String>,
 ) -> Result<String, Box<dyn ::std::error::Error>> {
-    let file_extension = match validate_artifact(&artifact, image.repository())? {
+    let file_extension = match validate_artifact(artifact, image.repository())? {
         SupportedArtifacts::Par => PROVIDER_ARCHIVE_FILE_EXTENSION,
         SupportedArtifacts::Wasm => WASM_FILE_EXTENSION,
     };
@@ -261,7 +292,7 @@ pub(crate) fn write_artifact(
         file_extension
     ));
     let mut f = File::create(outfile.clone())?;
-    f.write_all(&artifact)?;
+    f.write_all(artifact)?;
     Ok(outfile)
 }
 
@@ -306,13 +337,15 @@ fn validate_provider_archive(
 }
 
 pub(crate) async fn handle_push(cmd: PushCommand) -> Result<String, Box<dyn ::std::error::Error>> {
+    if cmd.url.starts_with("localhost:") && !cmd.opts.insecure {
+        warn!(" Unless an SSL certificate has been installed, pushing to localhost without the --insecure option will fail")
+    }
+
     let spinner = match cmd.output.kind {
-        OutputKind::Text { .. } if output_destination() == OutputDestination::Cli => {
-            Some(Spinner::new(
-                Spinners::Dots12,
-                format!(" Pushing {} to {} ...", cmd.artifact, cmd.url),
-            ))
-        }
+        OutputKind::Text => Some(Spinner::new(
+            &Spinners::Dots12,
+            format!(" Pushing {} to {} ...", cmd.artifact, cmd.url),
+        )),
         _ => None,
     };
     info!(" Pushing {} to {} ...", cmd.artifact, cmd.url);
@@ -398,6 +431,7 @@ pub(crate) async fn push_artifact(
         } else {
             ClientProtocol::Https
         },
+        ..Default::default()
     });
 
     let auth = match (user, password) {
@@ -489,7 +523,7 @@ mod tests {
                     digest.unwrap(),
                     "sha256:a17a163afa8447622055deb049587641a9e23243a6cc4411eb33bd4267214cf3"
                 );
-                assert_eq!(output.kind, OutputKind::Text { max_width: 0 });
+                assert_eq!(output.kind, OutputKind::Text);
                 assert_eq!(opts.user.unwrap(), "user");
                 assert_eq!(opts.password.unwrap(), "password");
             }
